pub enum PluginCommand {
New(NewPluginArgs),
Build(BuildPluginArgs),
Watch(WatchPluginArgs),
}Variants
New(NewPluginArgs)
Create a new plugin from template
Build(BuildPluginArgs)
Build a plugin’s backend and/or frontend components.
Customize the frontend build via broccoli.dev.toml in the
plugin directory. See broccoli plugin build --help for details.
Watch(WatchPluginArgs)
Watch a plugin for changes, auto-build and upload.
Watches plugin source files and automatically rebuilds, packages, and uploads the plugin to the server on each change.
Place a broccoli.dev.toml in the plugin directory to customize
watch behavior, frontend directory, and build commands. Run
broccoli plugin watch --help for details.