pub enum FileKind {
Backend,
Frontend,
PluginManifest,
Unknown,
}Expand description
Classify a changed file as backend, frontend, or unknown.
Uses file extension to determine the build target. The caller uses
frontend_dir to disambiguate files that could be either (e.g. .json
files exist in both Rust and JS projects, but we only treat them as
frontend if they’re inside the frontend directory).
Variants