should_ignore

Function should_ignore 

pub fn should_ignore(
    relative: &Path,
    extra_ignores: &[String],
    web_root_relative: Option<&Path>,
) -> bool
Check whether a path component matches any of the built-in or extra ignore patterns.

This checks directory names in the path. Glob-style patterns (e.g. *.log) are matched against the filename of the changed file.